@@ -61,7 +61,6 @@ import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
-import org.apache.commons.logging.Log;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
@@ -77,7 +76,6 @@ import com.openexchange.exception.OXException;
 import com.openexchange.groupware.container.Contact;
 import com.openexchange.java.Charsets;
 import com.openexchange.java.Streams;
-import com.openexchange.log.LogFactory;
 import com.openexchange.oauth.OAuthAccount;
 import com.openexchange.oauth.OAuthExceptionCodes;
 import com.openexchange.oauth.yahoo.YahooService;
@@ -93,11 +91,11 @@ import com.openexchange.threadpool.ThreadPools;
  */
 public class YahooServiceImpl implements YahooService {
 
-    private static final String ALL_CONTACT_IDS_URL = "http://social.yahooapis.com/v1/user/GUID/contacts?format=json";
+    private static final String ALL_CONTACT_IDS_URL = "https://social.yahooapis.com/v1/user/GUID/contacts?format=json";
 
-    private static final String SINGLE_CONTACT_URL = "http://social.yahooapis.com/v1/user/GUID/contact/CONTACT_ID?format=json";
+    private static final String SINGLE_CONTACT_URL = "https://social.yahooapis.com/v1/user/GUID/contact/CONTACT_ID?format=json";
 
-    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(YahooServiceImpl.class));
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(YahooServiceImpl.class);
 
     private final Pattern patternGuid;
     private final YahooOAuthActivator activator;
@@ -118,7 +116,7 @@ public class YahooServiceImpl implements YahooService {
             try {
                 account = oAuthService.getAccount(accountId, session, user, contextId);
             } catch (final OXException e) {
-                LOG.error(e.getMessage(), e);
+                LOG.error("", e);
                 return Collections.emptyList();
             }
             final Token accessToken = new Token(account.getToken(), account.getSecret());
@@ -133,17 +131,25 @@ public class YahooServiceImpl implements YahooService {
         // Get the GUID of the current user from yahoo. This is needed for later requests
         final String guid;
         {
-            final OAuthRequest guidRequest = new OAuthRequest(Verb.GET, "http://social.yahooapis.com/v1/me/guid?format=xml");
+            final OAuthRequest guidRequest = new OAuthRequest(Verb.GET, "https://social.yahooapis.com/v1/me/guid?format=xml");
             service.signRequest(accessToken, guidRequest);
             final Response guidResponse = guidRequest.send();
-
+            final String contentType = guidResponse.getHeader("Content-Type");
+            if (null == contentType || false == contentType.toLowerCase().contains("application/xml")) {
+                throw OAuthExceptionCodes.NOT_A_VALID_RESPONSE.create();
+            }
             final Matcher matcher = patternGuid.matcher(guidResponse.getBody());
             guid = matcher.find() ? matcher.group(1) : "";
         }
+
         // Now get the ids of all the users contacts
         OAuthRequest request = new OAuthRequest(Verb.GET, ALL_CONTACT_IDS_URL.replace("GUID", guid));
         service.signRequest(accessToken, request);
         final Response response = request.send();
+        final String contentType = response.getHeader("Content-Type");
+        if (null == contentType || false == contentType.toLowerCase().contains("application/json")) {
+            throw OAuthExceptionCodes.NOT_A_VALID_RESPONSE.create();
+        }
         request = null;
         try {
             final JSONObject allContactsWholeResponse = extractJson(response);
@@ -194,12 +200,12 @@ public class YahooServiceImpl implements YahooService {
             }
             return contactList;
         } catch (final JSONException e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
         } catch (final OXException e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
         } catch (final InterruptedException e) {
             Thread.currentThread().interrupt();
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
         }
         return Collections.emptyList();
     }
@@ -356,7 +362,7 @@ public class YahooServiceImpl implements YahooService {
                 }
             }
         } catch (final JSONException e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
         }
         return oxContact;
     }
@@ -369,7 +375,7 @@ public class YahooServiceImpl implements YahooService {
             final OAuthAccount account = oAuthService.getAccount(accountId, session, user, contextId);
             displayName = account.getDisplayName();
         } catch (final OXException e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
         }
         return displayName;
     }
