@@ -50,9 +50,8 @@
 package com.openexchange.oauth;
 
 import com.openexchange.exception.Category;
-import com.openexchange.exception.LogLevel;
-import com.openexchange.exception.LogLevelAwareOXExceptionCode;
 import com.openexchange.exception.OXException;
+import com.openexchange.exception.OXExceptionCode;
 import com.openexchange.exception.OXExceptionFactory;
 
 /**
@@ -61,84 +60,86 @@ import com.openexchange.exception.OXExceptionFactory;
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  * @since Open-Xchange v6.18.2
  */
-public enum OAuthExceptionCodes implements LogLevelAwareOXExceptionCode {
+public enum OAuthExceptionCodes implements OXExceptionCode {
 
     /**
      * An error occurred: %1$s
      */
-    UNEXPECTED_ERROR(OAuthExceptionMessages.UNEXPECTED_ERROR_MSG, CATEGORY_ERROR, 1, LogLevel.ERROR),
+    UNEXPECTED_ERROR(OAuthExceptionMessages.UNEXPECTED_ERROR_MSG, CATEGORY_ERROR, 1),
     /**
      * An I/O error occurred: %1$s
      */
-    IO_ERROR(OAuthExceptionMessages.IO_ERROR_MSG, CATEGORY_ERROR, 2, LogLevel.ERROR),
+    IO_ERROR(OAuthExceptionMessages.IO_ERROR_MSG, CATEGORY_ERROR, 2),
     /**
      * A JSON occurred: %1$s
      */
-    JSON_ERROR(OAuthExceptionMessages.JSON_ERROR_MSG, CATEGORY_ERROR, 3, LogLevel.ERROR),
+    JSON_ERROR(OAuthExceptionMessages.JSON_ERROR_MSG, CATEGORY_ERROR, 3),
     /**
      * Unknown OAuth service meta data: %1$s
      */
-    UNKNOWN_OAUTH_SERVICE_META_DATA(OAuthExceptionMessages.UNKNOWN_OAUTH_SERVICE_META_DATA_MSG, CATEGORY_ERROR, 4, LogLevel.ERROR),
+    UNKNOWN_OAUTH_SERVICE_META_DATA(OAuthExceptionMessages.UNKNOWN_OAUTH_SERVICE_META_DATA_MSG, CATEGORY_ERROR, 4),
     /**
      * A SQL error occurred: %1$s
      */
-    SQL_ERROR(OAuthExceptionMessages.SQL_ERROR_MSG, CATEGORY_ERROR, 5, LogLevel.ERROR),
+    SQL_ERROR(OAuthExceptionMessages.SQL_ERROR_MSG, CATEGORY_ERROR, 5),
     /**
      * Account not found with identifier %1$s for user %2$s in context %3$s.
      */
-    ACCOUNT_NOT_FOUND(OAuthExceptionMessages.ACCOUNT_NOT_FOUND_MSG, CATEGORY_USER_INPUT, 6, LogLevel.ERROR),
+    ACCOUNT_NOT_FOUND(OAuthExceptionMessages.ACCOUNT_NOT_FOUND_MSG, CATEGORY_USER_INPUT, 6),
     /**
      * Unsupported OAuth service: %1$s
      */
-    UNSUPPORTED_SERVICE(OAuthExceptionMessages.UNSUPPORTED_SERVICE_MSG, CATEGORY_ERROR, 7, LogLevel.ERROR),
+    UNSUPPORTED_SERVICE(OAuthExceptionMessages.UNSUPPORTED_SERVICE_MSG, CATEGORY_ERROR, 7),
     /**
      * Missing argument: %1$s
      */
-    MISSING_ARGUMENT(OAuthExceptionMessages.MISSING_ARGUMENT_MSG, CATEGORY_USER_INPUT, 8, LogLevel.ERROR),
+    MISSING_ARGUMENT(OAuthExceptionMessages.MISSING_ARGUMENT_MSG, CATEGORY_USER_INPUT, 8),
     /**
      * Your '%1$s' password changed. You have to authorize the server to use your account with the new password. To do so, go to Configuration -> My Social Configuration -> Accounts. Then try again.
      */
-    TOKEN_EXPIRED(OAuthExceptionMessages.TOKEN_EXPIRED_MSG, CATEGORY_TRY_AGAIN, 9, LogLevel.ERROR),
+    TOKEN_EXPIRED(OAuthExceptionMessages.TOKEN_EXPIRED_MSG, CATEGORY_TRY_AGAIN, 9),
     /**
      * An OAuth error occurred: %1$s
      */
-    OAUTH_ERROR(OAuthExceptionMessages.OAUTH_ERROR_MSG, CATEGORY_ERROR, 10, LogLevel.ERROR),
+    OAUTH_ERROR(OAuthExceptionMessages.OAUTH_ERROR_MSG, CATEGORY_ERROR, 10),
     /**
      * "The address %1 is not white-listed as for the %2 OAuth API"
      */
-    NOT_A_WHITELISTED_URL(OAuthExceptionMessages.NOT_A_WHITELISTED_URL_MSG, CATEGORY_PERMISSION_DENIED, 11, LogLevel.ERROR),
+    NOT_A_WHITELISTED_URL(OAuthExceptionMessages.NOT_A_WHITELISTED_URL_MSG, CATEGORY_PERMISSION_DENIED, 11),
     /**
      * The request sent was missing its body
      */
-    MISSING_BODY(OAuthExceptionMessages.MISSING_BODY_MSG, CATEGORY_USER_INPUT, 12, LogLevel.ERROR),
+    MISSING_BODY(OAuthExceptionMessages.MISSING_BODY_MSG, CATEGORY_USER_INPUT, 12),
     /**
      * The account is invalid, please recreate it.
      */
-    INVALID_ACCOUNT(OAuthExceptionMessages.INVALID_ACCOUNT_MSG, CATEGORY_TRY_AGAIN, 13, LogLevel.ERROR),
+    INVALID_ACCOUNT(OAuthExceptionMessages.INVALID_ACCOUNT_MSG, CATEGORY_TRY_AGAIN, 13),
     /**
      * Please provide a display name.
      */
-    MISSING_DISPLAY_NAME(OAuthExceptionMessages.MISSING_DISPLAY_NAME_MSG, CATEGORY_USER_INPUT, 14, LogLevel.ERROR),
+    MISSING_DISPLAY_NAME(OAuthExceptionMessages.MISSING_DISPLAY_NAME_MSG, CATEGORY_USER_INPUT, 14),
     /**
      * The associated OAuth provider denied the request: %1$s.
      */
-    DENIED_BY_PROVIDER(OAuthExceptionMessages.DENIED_BY_PROVIDER_MSG, CATEGORY_USER_INPUT, 15, LogLevel.ERROR),
+    DENIED_BY_PROVIDER(OAuthExceptionMessages.DENIED_BY_PROVIDER_MSG, CATEGORY_USER_INPUT, 15),
     /**
      * The OAuth authentication process has been canceled.
      */
-    CANCELED_BY_USER(OAuthExceptionMessages.CANCELED_BY_USER_MSG, CATEGORY_USER_INPUT, 16, LogLevel.ERROR),
+    CANCELED_BY_USER(OAuthExceptionMessages.CANCELED_BY_USER_MSG, CATEGORY_USER_INPUT, 16),
+    /**
+     * Could not get a valid response from the associated OAuth provider.
+     */
+    NOT_A_VALID_RESPONSE("Could not get a valid response from the associated OAuth provider.", CATEGORY_ERROR, 17)
     ;
 
     private final Category category;
     private final int number;
     private final String message;
-    private final LogLevel logLevel;
 
-    private OAuthExceptionCodes(final String message, final Category category, final int detailNumber, final LogLevel logLevel) {
+    private OAuthExceptionCodes(final String message, final Category category, final int detailNumber) {
         this.message = message;
         this.number = detailNumber;
         this.category = category;
-        this.logLevel = logLevel;
     }
 
     @Override
@@ -161,15 +162,6 @@ public enum OAuthExceptionCodes implements LogLevelAwareOXExceptionCode {
         return number;
     }
 
-    @Override
-    public LogLevel getLogLevel() {
-        return logLevel;
-    }
-
-    public String getHelp() {
-        return null;
-    }
-
     @Override
     public boolean equals(final OXException e) {
         return OXExceptionFactory.getInstance().equals(this, e);
